@@ -2,7 +2,7 @@
 #this repository contains the full copyright notices and license terms.
 from decimal import Decimal
 import operator
-from trytond.model import ModelView, ModelSQL, fields
+from trytond.model import ModelView, ModelSQL
 from trytond.pool import Pool
 
 
@@ -13,13 +13,14 @@ class InvoiceLine(ModelSQL, ModelView):
         '''
         Return account move for anglo-saxon stock accounting
         '''
-        assert type_.startswith('in_') or type_.startswith('out_'), 'wrong type'
+        assert type_.startswith('in_') or type_.startswith('out_'), \
+            'wrong type'
 
         result = []
         move_line = {}
         move_line['name'] = line.description
         move_line['amount_second_currency'] = Decimal('0.0')
-        move_line['second_currency'] = False
+        move_line['second_currency'] = None
 
         if type_.startswith('in_'):
             move_line['debit'] = amount
@@ -45,8 +46,6 @@ class InvoiceLine(ModelSQL, ModelView):
 
     def get_move_line(self, line):
         pool = Pool()
-        purchase_line_invoice_line_obj = pool.get(
-                'purchase.line-account.invoice.line')
         move_obj = pool.get('stock.move')
         currency_obj = pool.get('currency.currency')
 
@@ -56,7 +55,7 @@ class InvoiceLine(ModelSQL, ModelView):
             return result
         if not line.product:
             return result
-        if line.product.type == 'service':
+        if line.product.type != 'goods':
             return result
 
         moves = []
