@@ -8,7 +8,7 @@ from trytond.pool import Pool
 
 class Move(ModelSQL, ModelView):
     _name = 'stock.move'
-    anglo_saxon_quantity = fields.Float('Anglo-Saxon Quantity',
+    anglo_saxon_quantity = fields.Float('Anglo-Saxon Quantity', required=True,
         digits=(16, Eval('unit_digits', 2)), depends=['unit_digits'])
 
     def __init__(self):
@@ -22,6 +22,43 @@ class Move(ModelSQL, ModelView):
     def default_anglo_saxon_quantity(self):
         return 0.0
 
+    def _get_account_stock_move_lines(self, move, type_):
+        uom_obj = Pool().get('product.uom')
+        currency_obj = Pool().get('currency.currency')
+        lines = super(Move, self)._get_account_stock_move_lines(move, type_)
+        if (type_.endswith('supplier')
+                and move.product.cost_price_method == 'fixed'):
+            cost_price = uom_obj.compute_price(move.product.default_uom,
+                move.cost_price, move.uom)
+            amount = currency_obj.round(move.company.currency,
+                Decimal(str(move.quantity)) * (move.unit_price - cost_price))
+            if currency_obj.is_zero(move.company.currency, amount):
+                return lines
+            account_id = move.product.account_stock_supplier_used.id
+            for move_line in lines:
+                if move_line['account'] == account_id:
+                    break
+            else:
+                return lines
+            if type_.startswith('in_'):
+                move_line['credit'] += amount
+                debit = amount
+                credit = Decimal(0)
+            else:
+                move_line['debit'] += amount
+                debit = Decimal(0)
+                credit = amount
+            if amount < Decimal(0):
+                debit, credit = -credit, -debit
+            move_line = {
+                'name': move.rec_name,
+                'debit': debit,
+                'credit': credit,
+                'account': move.product.account_expense_used.id,
+                }
+            lines.append(move_line)
+        return lines
+
     def _get_anglo_saxon_move(self, moves, quantity):
         '''
         Generator of (move, qty) where move is the move to be consumed and qty
@@ -53,7 +90,8 @@ class Move(ModelSQL, ModelView):
 
         for move in moves:
             assert move.product == product, 'wrong product'
-        assert type_.startswith('in_') or type_.startswith('out_'), 'wrong type'
+        assert type_.startswith('in_') or type_.startswith('out_'), \
+            'wrong type'
 
         total_qty = uom_obj.compute_qty(uom, quantity, product.default_uom,
                 round=False)
@@ -81,4 +119,12 @@ class Move(ModelSQL, ModelView):
             cost += product.cost_price * Decimal(str(qty))
         return cost
 
+    def copy(self, ids, default=None):
+        if default is None:
+            default = {}
+        default = default.copy()
+        default.setdefault('anglo_saxon_quantity',
+            self.default_anglo_saxon_quantity())
+        return super(Move, self).copy(ids, default=default)
+
 Move()
